@@ -421,8 +421,18 @@ def main(_args=None):
     except KeyError:
         pass  # pdoc was not invoked while in a virtual environment
     else:
+        from glob import glob
         from distutils.sysconfig import get_python_lib
-        sys.path.append(get_python_lib(prefix=venv_dir))
+        libdir = get_python_lib(prefix=venv_dir)
+        sys.path.append(libdir)
+        # Resolve egg-links from `setup.py develop` or `pip install -e`
+        # XXX: Welcome a more canonical approach
+        for pth in glob(path.join(libdir, '*.egg-link')):
+            try:
+                with open(pth) as f:
+                    sys.path.append(path.join(libdir, f.readline().rstrip()))
+            except IOError:
+                warn('Invalid egg-link in venv: {!r}'.format(pth))
 
     if args.http:
         template_config['link_prefix'] = "/"
@@ -468,10 +478,10 @@ PDF-ready markdown written to standard output.
                               ^^^^^^^^^^^^^^^
 Convert this file to PDF using e.g. Pandoc:
 
-    pandoc --metadata=title:"MyProject Documentation"             \\
-           --toc --toc-depth=4 --from=markdown+abbreviations      \\
-           --pdf-engine=xelatex --variable=mainfont:"DejaVu Sans" \\
-           --output=pdf.pdf pdf.md
+    pandoc --metadata=title:"MyProject Documentation"               \\
+           --from=markdown+abbreviations+tex_math_single_backslash  \\
+           --pdf-engine=xelatex --variable=mainfont:"DejaVu Sans"   \\
+           --toc --toc-depth=4 --output=pdf.pdf  pdf.md
 
 or using Python-Markdown and Chrome/Chromium/WkHtmlToPDF:
 
